import pandas as pd


def join( Model_inst ):

    """Taking all Input Files from the Model, join them together in this fashion as follows """

    ### Insert joining instructions

    Model_inst.df_joined = pd.DataFrame()
